pub trait ErrLogger {
// Required methods
fn log_ef(self);
fn log_efd(self);
fn log_err(self) -> Self;
fn log_ed(self) -> Self;
fn log_ef_with(self, msg: impl Display);
fn log_efd_with(self, msg: impl Display);
fn log_err_with(self, msg: impl Display) -> Self;
fn log_ed_with(self, msg: impl Display) -> Self;
}Required Methods
Sourcefn log_ef_with(self, msg: impl Display)
fn log_ef_with(self, msg: impl Display)
log error and forget the result with message
Sourcefn log_efd_with(self, msg: impl Display)
fn log_efd_with(self, msg: impl Display)
log error as debug and forget the result with message
Sourcefn log_err_with(self, msg: impl Display) -> Self
fn log_err_with(self, msg: impl Display) -> Self
log error and keep the result with message
Sourcefn log_ed_with(self, msg: impl Display) -> Self
fn log_ed_with(self, msg: impl Display) -> Self
log error as debug and keep the result with message
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".